#
# spec file for package wayland
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libwayland0
Name:           wayland
Version:        1.9.0
Release:        2.5
Summary:        Wayland Compositor Infrastructure
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://wayland.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/wayland/wayland
#Git-Web:	http://cgit.freedesktop.org/wayland/wayland/
Source:         http://wayland.freedesktop.org/releases/%name-%version.tar.xz
Source2:        http://wayland.freedesktop.org/releases/%name-%version.tar.xz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
#git#BuildRequires:  autoconf >= 2.64
#git#BuildRequires:  automake >= 1.11
#git#BuildRequires:  libtool >= 2.2
BuildRequires:  fdupes
BuildRequires:  libxml2-tools
BuildRequires:  libxslt-tools
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libffi)
%define with_doc 0
%if 0%with_doc
BuildRequires:  doxygen
BuildRequires:  graphviz-gnome
BuildRequires:  xmlto
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Wayland is a protocol for a compositor to talk to its clients as well
as a C library implementation of that protocol. The compositor can be
a standalone display server running on Linux kernel modesetting and
evdev input devices, an X application, or a wayland client itself.
The clients can be traditional applications, X servers (rootless or
fullscreen) or other display servers.

%package -n libwayland-client0
Summary:        Wayland core client library
Group:          System/Libraries

%description -n libwayland-client0
Wayland is a protocol for a compositor to talk to its clients as well
as a C library implementation of that protocol. The compositor can be
a standalone display server running on Linux kernel modesetting and
evdev input devices, an X application, or a wayland client itself.
The clients can be traditional applications, X servers (rootless or
fullscreen) or other display servers.

%package -n libwayland-cursor0
Summary:        Wayland cursor library
Group:          System/Libraries

%description -n libwayland-cursor0
The purpose of this library is to be the equivalent of libXcursor in
the X world. This library is compatible with X cursor themes and
loads them directly into an shm pool making it easy for the clients
to get buffer for each cursor image.

%package -n libwayland-server0
Summary:        Wayland core server library
Group:          System/Libraries

%description -n libwayland-server0
Wayland is a protocol for a compositor to talk to its clients as well
as a C library implementation of that protocol. The compositor can be
a standalone display server running on Linux kernel modesetting and
evdev input devices, an X application, or a wayland client itself.
The clients can be traditional applications, X servers (rootless or
fullscreen) or other display servers.

%package devel
Summary:        Development files for the Wayland Compositor Infrastructure
Group:          Development/Libraries/C and C++
Requires:       libwayland-client0 = %version
Requires:       libwayland-cursor0 = %version
Requires:       libwayland-server0 = %version

%description devel
Wayland is a protocol for a compositor to talk to its clients as well
as a C library implementation of that protocol. The compositor can be
a standalone display server running on Linux kernel modesetting and
evdev input devices, an X application, or a wayland client itself.
The clients can be traditional applications, X servers (rootless or
fullscreen) or other display servers.

This package contains all necessary include files and libraries needed
to develop applications that require these.

%package doc
Summary:        Wayland development documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This subpackage contains the documentation to Wayland.

%prep
%setup -q

%build
if [ ! -e configure ]; then
	autoreconf -fi;
fi;
%configure --disable-static --includedir="%_includedir/%name" \
%if %with_doc
	--docdir="%_defaultdocdir/%name"
%else
	--disable-documentation
%endif
make %{?_smp_mflags}

%install
make DESTDIR="%buildroot" install %{?_smp_mflags}
find "%buildroot" -type f -name "*.la" -delete -print
%fdupes %buildroot/%_prefix

%check
%if !0%{?qemu_user_space_build}
mkdir -p xdg/wayland-tests
chmod 700 xdg xdg/wayland-tests
export XDG_RUNTIME_DIR="$PWD/xdg"
if ! make check V=1; then
	cat test-suite.log
	exit 1
fi
%endif

%post   -n libwayland-client0 -p /sbin/ldconfig
%postun -n libwayland-client0 -p /sbin/ldconfig
%post   -n libwayland-cursor0 -p /sbin/ldconfig
%postun -n libwayland-cursor0 -p /sbin/ldconfig
%post   -n libwayland-server0 -p /sbin/ldconfig
%postun -n libwayland-server0 -p /sbin/ldconfig

%files -n libwayland-client0
%defattr(-,root,root)
%_libdir/libwayland-client.so.0*

%files -n libwayland-cursor0
%defattr(-,root,root)
%_libdir/libwayland-cursor.so.0*

%files -n libwayland-server0
%defattr(-,root,root)
%_libdir/libwayland-server.so.0*

%files devel
%defattr(-,root,root)
%_bindir/wayland-scanner
%_includedir/%name/
%_libdir/libwayland-*.so
%_libdir/pkgconfig/wayland-*.pc
%_datadir/aclocal/
#%_datadir/pkgconfig/wayland-*.pc
%_datadir/wayland/

%if %with_doc
%files doc
%defattr(-,root,root)
%_mandir/man3/wl*.3*
%_docdir/%name/
%endif

%changelog
* Tue Sep 22 2015 jengelh@inai.de
- Update to new upstream release 1.9.0
  * This release brings fixes and modest refactoring.
- License was changed from MIT X11 to MIT Expat upstream.
* Wed Aug 26 2015 zaitor@opensuse.org
- Update to new upstream release 1.8.1
  * This is just a brown paper bag release. In rolling the wayland
  1.8.0 distribution tarball some files were set to read-only. This
  rectifies that. There are no file content changes.
* Wed Jun  3 2015 jengelh@inai.de
- Update to new upstream release 1.8.0
  * Wayland 1.8 splits the client and server header files into core
  and generated protocol. The core headers can be included as
  wayland-client-core.h and wayland-server-core.h. The scanner
  also now supports a --include-core-only option, which causes
  generated code to use only these core headers.
* Wed Mar  4 2015 jengelh@inai.de
- Update to new upstream release 1.7.0
  * Documentation updates
* Mon Feb  2 2015 jengelh@inai.de
- Update to new upstream prerelease 1.6.92
  * More documentation updates
* Tue Jan 27 2015 jengelh@inai.de
- Update to new upstream prerelease 1.6.91
  * The codebase's doxygen documentation was revamped
* Sun Jan 25 2015 jengelh@inai.de
- Update to new upstream release 1.6.1
  * Maintenance release for Wayland 1.6, with a handful of fixes
  pulled from the 1.7 tree that improve handling of several error
  situations between server and clients.
* Fri Sep 19 2014 jengelh@inai.de
- Update to new upstream release 1.6
  * Add error enums to wl_surface.
  * Add keyboard repeat information to wl_keyboard protocol.
  * Error handling additions in libwayland-client: when a protocol
  error happens, the program can query more detailed information
  about the error.
  * New wl_display_add_socket_auto() in libwayland-server:
  automatically find a free socket name.
  * Add wl_display_roundtrip_queue(): blocking round-trip on a
  custom queue.
  * Stop exposing wl_display global. Turns out binding to the
  global would have triggered bugs, and there was no proper use
  for it.
* Fri Sep 12 2014 jengelh@inai.de
- Update to version 1.5.93
  * Bug fixes
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 1.5.92:
  * wayland-client: Initialize newly created wl_proxys to zero.
  * client: add display_wakeup_threads function.
  * Doc and test updates / fixes.
* Wed May 21 2014 jengelh@inai.de
- Update to new upstream release 1.5.0
  * Use an internal event queue for wl_display events. This allows
  the client library to dispatch delete_id and error events
  immediately, even if the default queue is not dispatched.
* Fri Jan 24 2014 jengelh@inai.de
- Update to new upstream release 1.4.0
  * SHM Buffer SIBGUS protection
  * Subsurfaces protocol moved to wayland
- Remove wayland-1.3.93-resourcestest.patch
* Tue Jan 21 2014 tchvatal@suse.com
- Version bump to 1.3.93:
  * Various bugfixes to another RC release
- Add patch wayland-1.3.93-resourcestest.patch fixing tests from
  upstream git
- Cleanup the spec with spec-cleaner
- Always run tests do not conditionalize them. They wether fail or
  not
- Add missing dep on xsltproc as per configure
* Tue Dec 24 2013 jengelh@inai.de
- Update to new upstream release 1.3.91
  * protocol: add sub-surfaces to the core
* Thu Oct 17 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.0:
  * More pixel formats for wl_shm, such as RGB565
  * Multi resource support.
  * Support for language bindings
  * Release requests for wl_pointer, wl_keyboard and wl_touch
* Tue Oct 15 2013 dmueller@suse.com
- skip testsuite on QEMU Userspace build (fixes hang on ARMv6 build)
* Thu Sep 19 2013 hrvoje.senjan@gmail.com
- Update to new upstream release 1.2.1
  * Bug fixes and documentation tweaks
  * Touch support for toytoolkit and other clients.
* Mon Jul 15 2013 jengelh@inai.de
- Update to new upstream release 1.2.0
  * This release provides a stable wayland-server API and improved
  thread safety and relaxed thread-model assumptions in
  libwayland-client.
  * New features include color management, a subsurface protocol,
  output scaling (HiDPI), Rasperry Pi backend and renderer,
  and multi-seat support.
* Wed Apr 17 2013 jengelh@inai.de
- Update to new upstream release 1.1.0
  * Optimize damage handling when moving surfaces in and out of planes
  * Touch screen calibration feature and client
  * Proper support for popup surfaces
- Use a header location that does not change with every release
* Sun Mar 24 2013 hrvoje.senjan@gmail.com
- Update to new upstream release 1.0.6
  * protocol: remove implicit attach semantics
  * client: Invoke new_id closure arguments as pointers instead of integers
  * client: Check reference count only for destroyed proxies
  * client: add wl_proxy_get_class()
  * scanner: Fix 'destroy)' typo in check for destroy request presence
  * scanner: remove list_length in favor of wl_list_length
  * connection.c: Align pointer extra storage correctly
* Tue Dec 18 2012 jengelh@inai.de
- Update to new upstream release 1.0.3
  * a couple of documentation fixes
  * the test suite now cleans up its temporary files
* Sat Dec  1 2012 jengelh@inai.de
- Update to new upstream release 1.0.2
  * new wl_display_dispatch_queue_pending() entry point that allows
  avoiding triple buffering in Mesa
  * avoid premature exit and potential memory corruption in
  wl_display_roundtrip()
- Put all include files in a separate directory so that we see
  when downstream users forget to use pkgconfig
* Mon Nov 26 2012 tobias.johannes.klausmann@mni.thm.de
- Add initial baselibs.conf
  With this we can provide 32bit x86_64.rpm
* Tue Nov 20 2012 jengelh@inai.de
- Update to new upstream release 1.0.1
  * Supply a fix for out-of-order delete_id events, which allows
  to fix a crash that happens during EGLSurface destruction.
* Fri Nov  2 2012 cfarrell@suse.com
- license update: HPND
  http://spdx.org/licenses/HPND#licenseText
* Tue Oct 23 2012 jengelh@inai.de
- Update to new upstream release 1.0
  * more consistent error checking
* Fri Oct 19 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 0.99.0
  * responsible error handling
  * well-defined atomic update mechanism and event dispatching
  (thread safe)
  * Some API breakage
* Sat Feb 11 2012 jengelh@inai.de
- Initial package for build.opensuse.org (0.85)
